@@ -3,7 +3,7 @@
 /*                                                              */
 /* BGPView Shell Commands                                       */
 /****************************************************************/
-/* bvcommand.c,v 1.40 2001/07/30 08:53:49 kuniaki Exp */
+/* bvcommand.c,v 1.41 2001/08/02 06:29:06 kuniaki Exp */
 
 /*
  * Copyright (c) 2000 - 2001 Internet Initiative Japan Inc.
@@ -1971,7 +1971,7 @@ int bvc_show_bgpnexthop_sum(BVS_CMD_PARAM *prm)
 						listtmp->count++;
 						break;
 					}
-					if (listtmp == NULL) {
+					if (listtmp->next == NULL) {
 						listtmp->next = 
 							(NEXTHOP_LIST *)malloc(
 	                                                  sizeof(NEXTHOP_LIST));
