@@ -4,7 +4,7 @@
 /*                                                              */
 /* BGPView Shell 			                        */
 /****************************************************************/
-/* bvshell.c,v 1.44 2001/07/30 08:53:49 kuniaki Exp */
+/* bvshell.c,v 1.45 2001/08/02 05:01:49 kuniaki Exp */
 
 /*
  * Copyright (c) 2000 Internet Initiative Japan Inc.
@@ -483,7 +483,7 @@ int bvs_init_start()
 #ifdef DEBUG
 	printf("DEBUG: BVS Inline VTY Open -");
 #endif
-	if (((bvs_clients+bvs_maxcon-1)->clsock = open("/dev/null", O_WRONLY)) == NULL){
+	if (((bvs_clients+bvs_maxcon-1)->clsock = open("/dev/null", O_WRONLY)) == (int)NULL){
 		printf("Inline Virtual Terminal Could not open..\n");
 		return(1); 
 	}
